@@ -1,9 +1,7 @@
 package Log::Any::App;
 BEGIN {
-  $Log::Any::App::VERSION = '0.33';
+  $Log::Any::App::VERSION = '0.34';
 }
-# ABSTRACT: An easy way to use Log::Any in applications
-
 
 use 5.010;
 use strict;
@@ -20,6 +18,8 @@ use Log::Log4perl;
 # use Log::Dispatch::FileRotate
 # use Log::Dispatch::Syslog
 
+our $VERSION = '0.34'; # VERSION
+
 use vars qw($dbg_ctx);
 
 my %PATTERN_STYLES = (
@@ -30,7 +30,6 @@ my %PATTERN_STYLES = (
     syslog            => '[pid %p] %m',
 );
 
-
 my $init_args;
 our $init_called;
 my $is_daemon;
@@ -296,6 +295,7 @@ sub _parse_args {
 sub _parse_opts {
     my ($args, $caller) = @_;
     $args //= []; # if we don't import(), we never get args
+    _debug("parse_opts: args = [".join(", ", @$args)."]");
 
     my $spec = {
         name => _basename($0),
@@ -303,6 +303,7 @@ sub _parse_opts {
         dump => ($ENV{LOGANYAPP_DEBUG} ? 1:0),
         daemon => 0,
         category_alias => {},
+        level_flag_paths => [File::HomeDir->my_home, "/etc"],
     };
 
     my $i = 0;
@@ -317,7 +318,17 @@ sub _parse_opts {
         $i++;
     }
 
-    $spec->{level} = _set_level("", "");
+    if (defined $opts{name}) {
+        $spec->{name} = $opts{name};
+        delete $opts{name};
+    }
+
+    if (defined $opts{level_flag_paths}) {
+        $spec->{level_flag_paths} = $opts{level_flag_paths};
+        delete $opts{level_flag_paths};
+    }
+
+    $spec->{level} = _set_level("", "", $spec);
     if (!$spec->{level} && defined($opts{level})) {
         $spec->{level} = _check_level($opts{level}, "-level");
         _debug("Set general level to $spec->{level} (from -level)");
@@ -350,11 +361,6 @@ sub _parse_opts {
         delete $opts{init};
     }
 
-    if (defined $opts{name}) {
-        $spec->{name} = $opts{name};
-        delete $opts{name};
-    }
-
     if (defined $opts{daemon}) {
         $spec->{daemon} = $opts{daemon};
         $is_daemon = $opts{daemon};
@@ -462,7 +468,7 @@ sub _parse_opt_OUTPUT {
 
 sub _default_file {
     my ($spec) = @_;
-    my $level = _set_level("file", "file");
+    my $level = _set_level("file", "file", $spec);
     if (!$level) {
         $level = $spec->{level};
         _debug("Set level of file to $level (general level)");
@@ -509,7 +515,7 @@ sub _parse_opt_file {
 
 sub _default_dir {
     my ($spec) = @_;
-    my $level = _set_level("dir", "dir");
+    my $level = _set_level("dir", "dir", $spec);
     if (!$level) {
         $level = $spec->{level};
         _debug("Set level of dir to $level (general level)");
@@ -544,7 +550,7 @@ sub _parse_opt_dir {
 
 sub _default_screen {
     my ($spec) = @_;
-    my $level = _set_level("screen", "screen");
+    my $level = _set_level("screen", "screen", $spec);
     if (!$level) {
         $level = $spec->{level};
         _debug("Set level of screen to $level (general level)");
@@ -570,7 +576,7 @@ sub _parse_opt_screen {
 
 sub _default_syslog {
     my ($spec) = @_;
-    my $level = _set_level("syslog", "syslog");
+    my $level = _set_level("syslog", "syslog", $spec);
     if (!$level) {
         $level = $spec->{level};
         _debug("Set level of syslog to $level (general level)");
@@ -647,7 +653,8 @@ sub _check_level {
 }
 
 sub _set_level {
-    my ($prefix, $which) = @_;
+    my ($prefix, $which, $spec) = @_;
+    #use Data::Dumper; print Dumper $spec;
     my $p_ = $prefix ? "${prefix}_" : "";
     my $P_ = $prefix ? uc("${prefix}_") : "";
     my $F_ = $prefix ? ucfirst("${prefix}_") : "";
@@ -727,6 +734,38 @@ sub _set_level {
             }
         }
 
+        for my $dir (@{$spec->{level_flag_paths}}) {
+            for (@label2level) {
+                my $filename = "$dir/$spec->{name}." . $P_ . "log_level";
+                my $exists = -f $filename;
+                my $content;
+                if ($exists) {
+                    open my($f), $filename;
+                    $content = <$f>;
+                    chomp($content) if defined($content);
+                    close $f;
+                }
+                _debug("Checking level flag file content $filename: ",
+                       (defined($content) ? $content : "(undef)"));
+                if (defined $content) {
+                    $level = _check_level($content,
+                                          "level flag file $filename");
+                    $from = $filename;
+                    last SET;
+                }
+
+                $filename = "$dir/$spec->{name}." . $P_ . uc($_->[0]);
+                $exists = -e $filename;
+                _debug("Checking level flag file $filename: ",
+                       ($exists ? "EXISTS" : 0));
+                if ($exists) {
+                    $level = $_->[1];
+                    $from = $filename;
+                    last SET;
+                }
+            }
+        }
+
         no strict 'refs';
         for ("${F_}Log_Level", "${P_}LOG_LEVEL", "${p_}log_level",
              "${F_}LogLevel",  "${P_}LOGLEVEL",  "${p_}loglevel") {
@@ -796,9 +835,9 @@ sub import {
     }
 }
 
-
-
 1;
+# ABSTRACT: An easy way to use Log::Any in applications
+
 
 __END__
 =pod
@@ -809,7 +848,7 @@ Log::Any::App - An easy way to use Log::Any in applications
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -907,17 +946,41 @@ logs in your application (only in the modules).
 
 =head2 Changing logging level
 
-Changing logging level can be done from the script or outside the script. From
-the script:
+Since one of the most commonly tweaked logging setting is level (for example:
+increasing level when debugging problems), Log::Any::App provides several
+mechanisms to change log level, either from the script or from outside the
+script, for your convenience. Below are the mechanisms, ordered from highest
+priority:
+
+=over 4
+
+=item * import argument (inside the script)
+
+=item * command line arguments (outside the script)
+
+=item * environment variables (outside the script)
+
+=item * level flag files (outside the script)
+
+=item * variables in 'main' package (inside the script)
+
+=back
+
+These mechanisms are explained in more details in the documentation for the
+B<init()> function. But below are some examples.
+
+To change level from inside the script:
 
  use Log::Any::App '$log', -level => 'debug';
 
-but oftentimes what you want is changing level without modifying the script
-itself.
+This is useful if you want a fixed level that cannot be overriden by other
+mechanisms (since setting level using import argument has the highest priority).
+But oftentimes what you want is changing level without modifying the script
+itself. Thereby, just write:
 
  use Log::Any::App '$log';
 
-and then you can use environment variable:
+and then you can use environment variables to change level:
 
  TRACE=1 script.pl;         # setting level to trace
  DEBUG=1 script.pl;         # setting level to debug
@@ -933,21 +996,23 @@ or command-line options:
  script.pl --quiet
  script.pl --log_level=debug;   # '--log-level debug' will also do
 
-Log::Any::App won't consume the command-line options from @ARGV and thus won't
-interfere with command-line processing modules like L<Getopt::Long> or
-L<App::Options>. You might want to define these options in your option
-processing module though, or it might complain about unknown options. Or
-alternatively you can use environment variables instead.
+Regarding command-line options: Log::Any::App won't consume the command-line
+options from @ARGV and thus won't interfere with command-line processing modules
+like L<Getopt::Long> or L<App::Options>. If you use a command-line processing
+module and plan to use command-line options to set level, you might want to
+define these level options, or your command-line processing module will complain
+about unknown options.
 
 =head2 Changing default level
 
-The default log level is 'warn'. You can change this using:
+The default log level is 'warn'. To change the default level, you can use 'main'
+package variables (since they have the lowest priority):
 
  use Log::Any::App '$log';
- BEGIN { our $Log_Level = 'info' }
+ BEGIN { our $Log_Level = 'info' } # be more verbose by default
 
-and then you can still use environment or command-line options to override the
-setting.
+Then you will still be able to use level flag files or environment variables or
+command-line options to override this setting.
 
 =head2 Changing per-output level
 
@@ -964,10 +1029,9 @@ default 'warn' level:
  script.pl --screen-debug
  script.pl --screen-trace=1
  script.pl --screen-log-level=info
- # and so on
 
 Similarly, to set only file level, use FILE_VERBOSE, FILE_LOG_LEVEL,
---file-trace, etc.
+--file-trace, and so on.
 
 =head2 Setting default per-output level
 
@@ -993,21 +1057,40 @@ or:
 
  use Log::Any::App '$log', -screen => {level=>'off'};
 
-and this won't allow it to be reenabled from outside the script. However if you
-do this:
+and this won't allow the output to be reenabled from outside the script. However
+if you do this:
 
  use Log::Any::App;
  BEGIN { our $Screen_Log_Level = 'off' }
 
 then by default screen logging is turned off but you will be able to override
-the screen log level using environment or command-line options (SCREEN_DEBUG,
---screen-verbose, and so on).
+the screen log level using level flag files or environment variables or
+command-line options (SCREEN_DEBUG, --screen-verbose, and so on).
+
+=head2 Changing log level of cron scripts
+
+Environment variables and command-line options allow changing log level without
+modifying the script. But for scripts specified in crontab, they still require
+changing crontab entries, e.g.:
+
+ # turn on debugging
+ */5 * * * * DEBUG=1 foo
+
+ # be silent
+ */5 * * * * bar --quiet
+
+Another mechanism, level flag file, is useful in this case. By doing:
+
+ $ echo debug > ~/foo.log_level
+ # touch /etc/bar.QUIET
+
+you can also change log levels without modifying your crontab.
 
 =head2 Changing log file name/location
 
-By default Log::Any::App will use ~/$NAME.log (or /var/log/$NAME.log if script
-is running as root), where $NAME is taken from the basename of $0. But this can
-be changed using:
+By default Log::Any::App will log to file to ~/$NAME.log (or /var/log/$NAME.log
+if script is running as root), where $NAME is taken from the basename of $0. But
+this can be changed using:
 
  use Log::Any::App '$log', -name => 'myprog';
 
@@ -1102,8 +1185,15 @@ screen:
 =head2 Preventing logging level to be changed from outside the script
 
 Sometimes, for security/audit reasons, you don't want to allow script caller to
-change logging level. To do so, just specify the 'level' option in the script
-during 'use' statement.
+change logging level. As explained previously, you can use the 'level' import
+argument (the highest priority of level-setting):
+
+ use Log::Any::App '$log', -level => 'debug'; # always use debug level
+
+TODO: Allow something like 'debug+' to allow other mechanisms to *increase* the
+level but not decrease it. Or 'debug-' to allow other mechanisms to decrease
+level but not increase it. And finally 'debug,trace' to specify allowable levels
+(is this necessary?)
 
 =head2 Debugging
 
@@ -1148,6 +1238,10 @@ module, right?)
 
 Change the program name. Default is taken from $0.
 
+=item -level_flag_paths => ARRAY OF STRING
+
+Edit level flag file locations. The default is [$homedir, "/etc"].
+
 =item -daemon => BOOL
 
 Declare that script is a daemon. Default is no. Aside from this, to declare that
@@ -1182,23 +1276,28 @@ certain categories/modules.
 Specify log level for all outputs. Each output can override this value. The
 default log level is determined as follow:
 
-If L<App::Options> is present, these keys are checked in B<%App::options>:
-B<log_level>, B<trace> (if true then level is C<trace>), B<debug> (if true then
-level is C<debug>), B<verbose> (if true then level is C<info>), B<quiet> (if
-true then level is C<error>).
+B<Search in command-line options>. If L<App::Options> is present, these keys are
+checked in B<%App::options>: B<log_level>, B<trace> (if true then level is
+C<trace>), B<debug> (if true then level is C<debug>), B<verbose> (if true then
+level is C<info>), B<quiet> (if true then level is C<error>).
 
 Otherwise, it will try to scrape @ARGV for the presence of B<--log-level>,
 B<--trace>, B<--debug>, B<--verbose>, or B<--quiet> (this usually works because
 Log::Any::App does this in the INIT phase, before you call L<Getopt::Long>'s
 GetOptions() or the like).
 
-Otherwise, it will look for environment variables: B<LOG_LEVEL>, B<QUIET>.
-B<VERBOSE>, B<DEBUG>, B<TRACE>.
+B<Search in environment variables>. Otherwise, it will look for environment
+variables: B<LOG_LEVEL>, B<QUIET>. B<VERBOSE>, B<DEBUG>, B<TRACE>.
 
-Otherwise, it will try to search for package variables in the C<main> namespace
-with names like C<$Log_Level> or C<$LOG_LEVEL> or C<$log_level>, C<$Quiet> or
-C<$QUIET> or C<$quiet>, C<$Verbose> or C<$VERBOSE> or C<$verbose>, C<$Trace> or
-C<$TRACE> or C<$trace>, C<$Debug> or C<$DEBUG> or C<$debug>.
+B<Search in level flag files>. Otherwise, it will look for existence of files
+with one of these names C<$NAME.QUIET>, C<$NAME.VERBOSE>, C<$NAME.TRACE>,
+C<$NAME.DEBUG>, or content of C<$NAME.log_level> in ~ or /etc.
+
+B<Search in main package variables>. Otherwise, it will try to search for
+package variables in the C<main> namespace with names like C<$Log_Level> or
+C<$LOG_LEVEL> or C<$log_level>, C<$Quiet> or C<$QUIET> or C<$quiet>, C<$Verbose>
+or C<$VERBOSE> or C<$verbose>, C<$Trace> or C<$TRACE> or C<$trace>, C<$Debug> or
+C<$DEBUG> or C<$debug>.
 
 If everything fails, it defaults to 'warn'.
 
@@ -1236,9 +1335,9 @@ directory and the final file path is directory appended with $NAME.log.
 Default rotating behaviour is no rotate (max_size = 0).
 
 Default level for file is the same as the global level set by B<-level>. But
-App::options, command line, environment, and package variables in main are also
-searched first (for B<FILE_LOG_LEVEL>, B<FILE_TRACE>, B<FILE_DEBUG>,
-B<FILE_VERBOSE>, B<FILE_QUIET>, and the similars).
+App::options, command line, environment, level flag file, and package variables
+in main are also searched first (for B<FILE_LOG_LEVEL>, B<FILE_TRACE>,
+B<FILE_DEBUG>, B<FILE_VERBOSE>, B<FILE_QUIET>, and the similars).
 
 =item -dir => 0 | 1|yes|true | PATH | {opts} | [{opts}, ...]
 
@@ -1273,9 +1372,9 @@ C<-name>.
 Default rotating parameters are: histories=1000, max_size=0, max_age=undef.
 
 Default level for dir logging is the same as the global level set by B<-level>.
-But App::options, command line, environment, and package variables in main are
-also searched first (for B<DIR_LOG_LEVEL>, B<DIR_TRACE>, B<DIR_DEBUG>,
-B<DIR_VERBOSE>, B<DIR_QUIET>, and the similars).
+But App::options, command line, environment, level flag file, and package
+variables in main are also searched first (for B<DIR_LOG_LEVEL>, B<DIR_TRACE>,
+B<DIR_DEBUG>, B<DIR_VERBOSE>, B<DIR_QUIET>, and the similars).
 
 =item -screen => 0 | 1|yes|true | {opts}
 
@@ -1295,9 +1394,10 @@ How Log::Any::App determines defaults for screen logging:
 Screen logging is turned on by default.
 
 Default level for screen logging is the same as the global level set by
-B<-level>. But App::options, command line, environment, and package variables in
-main are also searched first (for B<SCREEN_LOG_LEVEL>, B<SCREEN_TRACE>,
-B<SCREEN_DEBUG>, B<SCREEN_VERBOSE>, B<SCREEN_QUIET>, and the similars).
+B<-level>. But App::options, command line, environment, level flag file, and
+package variables in main are also searched first (for B<SCREEN_LOG_LEVEL>,
+B<SCREEN_TRACE>, B<SCREEN_DEBUG>, B<SCREEN_VERBOSE>, B<SCREEN_QUIET>, and the
+similars).
 
 Color can also be turned on/off using environment variable COLOR (if B<color>
 argument is not set).
@@ -1323,9 +1423,10 @@ otherwise the default is off.
 Ident is program's name by default ($0, or C<-name>).
 
 Default level for syslog logging is the same as the global level set by
-B<-level>. But App::options, command line, environment, and package variables in
-main are also searched first (for B<SYSLOG_LOG_LEVEL>, B<SYSLOG_TRACE>,
-B<SYSLOG_DEBUG>, B<SYSLOG_VERBOSE>, B<SYSLOG_QUIET>, and the similars).
+B<-level>. But App::options, command line, environment, level flag file, and
+package variables in main are also searched first (for B<SYSLOG_LOG_LEVEL>,
+B<SYSLOG_TRACE>, B<SYSLOG_DEBUG>, B<SYSLOG_VERBOSE>, B<SYSLOG_QUIET>, and the
+similars).
 
 =item -dump => BOOL
 
